@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,14 +14,12 @@ RichTextComposerWidgetTest::RichTextComposerWidgetTest(QObject *parent)
 {
 }
 
-RichTextComposerWidgetTest::~RichTextComposerWidgetTest()
-{
-}
+RichTextComposerWidgetTest::~RichTextComposerWidgetTest() = default;
 
 void RichTextComposerWidgetTest::shouldHaveDefaultValue()
 {
     KPIMTextEdit::RichTextComposerWidget w;
-    auto *composer = w.findChild<KPIMTextEdit::RichTextComposer *>(QStringLiteral("richtextcomposer"));
+    auto composer = w.findChild<KPIMTextEdit::RichTextComposer *>(QStringLiteral("richtextcomposer"));
     QVERIFY(composer);
     QVERIFY(w.richTextComposer());
 }
