@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,6 +21,7 @@
 #include <QColorDialog>
 #include <QIcon>
 #include <QPointer>
+#include <QRegExp>
 #include <QTextBlock>
 #include <QTextDocumentFragment>
 #include <QTextList>
@@ -672,7 +673,7 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::fixupTextEditS
 
     // Get rid of embedded images, see QTextImageFormat documentation:
     // "Inline images are represented by an object replacement character (0xFFFC in Unicode) "
-    text.remove(0xFFFC);
+    text.remove(QChar(0xFFFC));
 
     // In plaintext mode, each space is non-breaking.
     text.replace(QChar::Nbsp, QChar::fromLatin1(' '));
