@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,6 @@
 #include "emoticonunicodeproxymodel.h"
 #include "textutils.h"
 #include <KLocalizedString>
-#include <QDebug>
 
 using namespace KPIMTextEdit;
 EmoticonUnicodeTab::EmoticonUnicodeTab(QWidget *parent)
@@ -29,9 +28,7 @@ EmoticonUnicodeTab::EmoticonUnicodeTab(QWidget *parent)
     connect(EmoticonUnicodeModelManager::self(), &EmoticonUnicodeModelManager::usedIdentifierChanged, this, &EmoticonUnicodeTab::slotUsedIdentifierChanged);
 }
 
-EmoticonUnicodeTab::~EmoticonUnicodeTab()
-{
-}
+EmoticonUnicodeTab::~EmoticonUnicodeTab() = default;
 
 void EmoticonUnicodeTab::searchUnicode(const QString &str)
 {
@@ -74,7 +71,7 @@ void EmoticonUnicodeTab::createEmoticonTab(const QString &str, const QVector<Emo
 {
     if (!emoticons.isEmpty()) {
         auto emojisView = new EmoticonListView(this);
-        EmoticonUnicodeProxyModel *emoticonUnicodeProxyModel = new EmoticonUnicodeProxyModel(this);
+        auto emoticonUnicodeProxyModel = new EmoticonUnicodeProxyModel(this);
         const auto emoji = emoticons.constFirst();
         emoticonUnicodeProxyModel->setCategories(emoji.emoticonCategory);
         emoticonUnicodeProxyModel->setSourceModel(EmoticonUnicodeModelManager::self()->emoticonUnicodeModel());
