@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,9 +15,12 @@
 #include <KSharedConfig>
 #include <KStandardAction>
 #include <KStandardGuiItem>
+#include <QActionGroup>
 #include <QIcon>
 
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
 #include "texttospeech/texttospeech.h"
+#endif
 #include <Sonnet/Dialog>
 #include <sonnet/backgroundchecker.h>
 
@@ -32,7 +35,7 @@
 
 #include <sonnet/spellcheckdecorator.h>
 
-#include <SonnetCore/sonnet/speller.h>
+#include <sonnet/speller.h>
 
 #include <Sonnet/Highlighter>
 
@@ -154,7 +157,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
                 popup->addAction(autoSpellCheckAction);
 
                 if (checkSpellingEnabled() && d->activateLanguageMenu) {
-                    QMenu *languagesMenu = new QMenu(i18n("Spell Checking Language"), popup);
+                    auto languagesMenu = new QMenu(i18n("Spell Checking Language"), popup);
                     auto languagesGroup = new QActionGroup(languagesMenu);
                     languagesGroup->setExclusive(true);
 
@@ -180,6 +183,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
             }
         }
         if (d->supportFeatures & TextToSpeech) {
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
             if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
                 if (!emptyDocument) {
                     QAction *speakAction = popup->addAction(i18n("Speak Text"));
@@ -187,6 +191,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
                     connect(speakAction, &QAction::triggered, this, &PlainTextEditor::slotSpeakText);
                 }
             }
+#endif
         }
         if (webShortcutSupport() && textCursor().hasSelection()) {
             popup->addSeparator();
@@ -814,7 +819,7 @@ void PlainTextEditor::clearDecorator()
 
 void PlainTextEditor::createHighlighter()
 {
-    Sonnet::Highlighter *highlighter = new Sonnet::Highlighter(this);
+    auto highlighter = new Sonnet::Highlighter(this);
     highlighter->setCurrentLanguage(spellCheckingLanguage());
     setHighlighter(highlighter);
 }
