@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,16 +16,18 @@
 #include <KSharedConfig>
 #include <KStandardAction>
 #include <KStandardGuiItem>
+#include <QActionGroup>
 #include <QIcon>
 
 #include <KIO/KUriFilterSearchProviderActions>
 #include <Sonnet/Dialog>
 #include <Sonnet/Highlighter>
-#include <SonnetCore/sonnet/backgroundchecker.h>
 #include <sonnet/backgroundchecker.h>
 #include <sonnet/spellcheckdecorator.h>
 #include <sonnet/speller.h>
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
 #include <texttospeech/texttospeech.h>
+#endif
 
 #include <QApplication>
 #include <QClipboard>
@@ -246,7 +248,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
             allowTabAction->setChecked(!tabChangesFocus());
             connect(allowTabAction, &QAction::triggered, this, &RichTextEditor::slotAllowTab);
         }
-
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
         if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
             if (!emptyDocument) {
                 QAction *speakAction = popup->addAction(i18n("Speak Text"));
@@ -254,6 +256,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
                 connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
             }
         }
+#endif
         if (webShortcutSupport() && textCursor().hasSelection()) {
             popup->addSeparator();
             const QString selectedText = textCursor().selectedText();
@@ -459,9 +462,9 @@ void RichTextEditor::checkSpelling(bool force)
         }
     }
     auto spellDialog = new Sonnet::Dialog(backgroundSpellCheck, force ? this : nullptr);
-    auto *buttonBox = spellDialog->findChild<QDialogButtonBox *>();
+    auto buttonBox = spellDialog->findChild<QDialogButtonBox *>();
     if (buttonBox) {
-        QPushButton *skipButton = new QPushButton(i18n("Skip"));
+        auto skipButton = new QPushButton(i18n("Skip"));
         buttonBox->addButton(skipButton, QDialogButtonBox::ActionRole);
         connect(skipButton, &QPushButton::clicked, spellDialog, &Sonnet::Dialog::close);
         if (force) {
@@ -549,7 +552,7 @@ void RichTextEditor::highlightWord(int length, int pos)
 
 void RichTextEditor::createHighlighter()
 {
-    Sonnet::Highlighter *highlighter = new Sonnet::Highlighter(this);
+    auto highlighter = new Sonnet::Highlighter(this);
     highlighter->setCurrentLanguage(spellCheckingLanguage());
     setHighlighter(highlighter);
 }
