@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -39,7 +39,7 @@ Q_SIGNALS:
 
 private:
     void slotPlayPause();
-    TextToSpeechActionsPrivate *const d;
+    std::unique_ptr<TextToSpeechActionsPrivate> const d;
 };
 }
 
