@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ using namespace KPIMTextEdit;
 class Q_DECL_HIDDEN KPIMTextEdit::TextToSpeechWidgetPrivate
 {
 public:
-    TextToSpeechWidgetPrivate()
-    {
-    }
+    TextToSpeechWidgetPrivate() = default;
 
     QPointer<KPIMTextEdit::TextToSpeechConfigDialog> mConfigDialog;
     QToolButton *mStopButton = nullptr;
